@@ -4,13 +4,10 @@ import random
 import math
 
 UNIX_reference = 1645678800
-jumbled_words = random.shuffle(words)
+jumbled_words = random.sample(words, len(words))
 
 def random_answer(daily: bool):
     """Picks a random answer every day."""
-
-    UNIX_reference = 1645678800
-    jumbled_words = random.shuffle(words)
     if daily == True:
         UNIX = dt.now().timestamp()
         iteration = int(math.floor((UNIX - UNIX_reference)/86400000))
